PolicyKit: Branch 'master'

David Zeuthen david at kemper.freedesktop.org
Wed Jul 25 15:02:50 PDT 2007


 polkit/polkit-policy-file-entry.c |   16 ++++++++--------
 polkit/polkit-policy-file-entry.h |    6 +++---
 tools/polkit-list-actions.c       |    4 ++--
 3 files changed, 13 insertions(+), 13 deletions(-)

New commits:
diff-tree 0da3d306107ff0f6958dba70ff585dc0e66cfbff (from bc1a540a0dc297bed4d21aedcc718b929d8fed4d)
Author: David Zeuthen <davidz at redhat.com>
Date:   Wed Jul 25 18:02:54 2007 -0400

    fix up proper naming of some methods on the PolKitPolicyFileEntry class

diff --git a/polkit/polkit-policy-file-entry.h b/polkit/polkit-policy-file-entry.h
index 0956507..7eac213 100644
--- a/polkit/polkit-policy-file-entry.h
+++ b/polkit/polkit-policy-file-entry.h
@@ -44,9 +44,9 @@ const char            *polkit_policy_fil
 const char            *polkit_policy_file_entry_get_group_id (PolKitPolicyFileEntry *policy_file_entry);
 PolKitPolicyDefault   *polkit_policy_file_entry_get_default  (PolKitPolicyFileEntry *policy_file_entry);
 
-const char            *polkit_policy_file_get_group_description (PolKitPolicyFileEntry *policy_file_entry);
-const char            *polkit_policy_file_get_action_description (PolKitPolicyFileEntry *policy_file_entry);
-const char            *polkit_policy_file_get_action_message (PolKitPolicyFileEntry *policy_file_entry);
+const char            *polkit_policy_file_entry_get_group_description (PolKitPolicyFileEntry *policy_file_entry);
+const char            *polkit_policy_file_entry_get_action_description (PolKitPolicyFileEntry *policy_file_entry);
+const char            *polkit_policy_file_entry_get_action_message (PolKitPolicyFileEntry *policy_file_entry);
 
 
 #endif /* POLKIT_POLICY_FILE_ENTRY_H */
diff --git a/tools/polkit-list-actions.c b/tools/polkit-list-actions.c
index aab23a0..4a674c0 100644
--- a/tools/polkit-list-actions.c
+++ b/tools/polkit-list-actions.c
@@ -78,9 +78,9 @@ _print_entry (PolKitPolicyCache *policy_
                 "default_active    = %s\n"
                 "\n", 
                 group_id, 
-                polkit_policy_file_get_group_description (pfe),
+                polkit_policy_file_entry_get_group_description (pfe),
                 action_id,
-                polkit_policy_file_get_action_description (pfe),
+                polkit_policy_file_entry_get_action_description (pfe),
                 polkit_result_to_string_representation (default_inactive),
                 polkit_result_to_string_representation (default_active));
 }


More information about the hal-commit mailing list
diff --git a/polkit/polkit-policy-file-entry.c b/polkit/polkit-policy-file-entry.c
index 1e10f96..ec26291 100644
--- a/polkit/polkit-policy-file-entry.c
+++ b/polkit/polkit-policy-file-entry.c
@@ -119,7 +119,7 @@ _polkit_policy_file_entry_set_descriptio
 }
 
 /**
- * polkit_policy_file_get_group_description:
+ * polkit_policy_file_entry_get_group_description:
  * @policy_file_entry: the object
  * 
  * Get the description of the group that this policy entry describes.
@@ -131,19 +131,19 @@ _polkit_policy_file_entry_set_descriptio
  * Returns: string or #NULL if descriptions are not loaded - caller shall not free this string
  **/
 const char *
-polkit_policy_file_get_group_description (PolKitPolicyFileEntry *policy_file_entry)
+polkit_policy_file_entry_get_group_description (PolKitPolicyFileEntry *policy_file_entry)
 {
         g_return_val_if_fail (policy_file_entry != NULL, NULL);
         return policy_file_entry->group_description;
 }
 
 /**
- * polkit_policy_file_get_action_description:
+ * polkit_policy_file_entry_get_action_description:
  * @policy_file_entry: the object
  * 
  * Get the description of the action that this policy entry describes. This
  * is intended to be used in policy editors, for example "Mount internal
  * volumes". Contrast with polkit_policy_file_get_action_message(). The
  * textual string will be returned in the current locale.
  *
  * Note, if polkit_context_set_load_descriptions() on the
@@ -153,20 +153,20 @@ polkit_policy_file_get_group_description
  * Returns: string or #NULL if descriptions are not loaded - caller shall not free this string
  **/
 const char *
-polkit_policy_file_get_action_description (PolKitPolicyFileEntry *policy_file_entry)
+polkit_policy_file_entry_get_action_description (PolKitPolicyFileEntry *policy_file_entry)
 {
         g_return_val_if_fail (policy_file_entry != NULL, NULL);
         return policy_file_entry->policy_description;
 }
 
 /**
- * polkit_policy_file_get_action_message:
+ * polkit_policy_file_entry_get_action_message:
  * @policy_file_entry: the object
  * 
  * Get the message describing the action that this policy entry
  * describes. This is to be used in dialogs, for example "System
  * Policy prevents mounting this volume". Contrast with
  * polkit_policy_file_get_action_description(). The textual string
  * will be returned in the current locale.
  *
  * Note, if polkit_context_set_load_descriptions() on the
@@ -176,7 +176,7 @@ polkit_policy_file_get_action_descriptio
  * Returns: string or #NULL if descriptions are not loaded - caller shall not free this string
  **/
 const char *
-polkit_policy_file_get_action_message (PolKitPolicyFileEntry *policy_file_entry)
+polkit_policy_file_entry_get_action_message (PolKitPolicyFileEntry *policy_file_entry)
 {
         g_return_val_if_fail (policy_file_entry != NULL, NULL);
         return policy_file_entry->policy_message;
@@ -131,19 +131,19 @@ _polkit_policy_file_entry_set_descriptio
  * Get the description of the action that this policy entry describes. This
  * is intended to be used in policy editors, for example "Mount internal
- * volumes". Contrast with polkit_policy_file_get_action_message(). The
+ * volumes". Contrast with polkit_policy_file_entry_get_action_message(). The
  * textual string will be returned in the current locale.
  *
@@ -153,20 +153,20 @@ polkit_policy_file_get_group_description
  * describes. This is to be used in dialogs, for example "System
  * Policy prevents mounting this volume". Contrast with
- * polkit_policy_file_get_action_description(). The textual string
+ * polkit_policy_file_entry_get_action_description(). The textual string
  * will be returned in the current locale.
  *